@@ -24,6 +24,7 @@ class RDFManifest(Manifest):
         self.filepath = filepath
         self.format = format
         if path.isfile(self.filepath):
+            logger.debug(self.filepath + " exists - loading rdf")
             self.revert()
 
     def revert(self):
@@ -33,8 +34,9 @@ class RDFManifest(Manifest):
                 self.from_string(m_str, self.format)
             except Exception, e:
                 # likely an empty or unparsable file
-                logger.error("RDFManifest was unable to read or parse file: %s in format: %s" % (self.filepath, self.format))
-                logger.error("Error: %s" % e)
+                logger.debug("RDFManifest was unable to read or parse file: %s in format: %s" % (self.filepath, self.format))
+                logger.debug("This can happen if no triples have been added for this object.")
+                logger.debug("Error: %s" % e)
                 
 
     def sync(self):
