@@ -263,7 +263,7 @@ class HarvestedRecord(object):
             if detailed:
                 d_parts = {}
                 for part in parts:
-                    d_parts[part] = self.stat(os.path.join("__"+str(self.manifest['currentversion']),subpath, part))
+                    d_parts[part] = self.stat(os.path.join(subpath, part))
                 return d_parts
             else:
                 return parts
